# Intelligent Transportation Systems

<!--toc:start-->
- [Intelligent Transportation Systems](#intelligent-transportation-systems)
  - [Introduction to ITS: A key component in smart cities](#introduction-to-its-a-key-component-in-smart-cities)
    - [Variants:](#variants)
    - [Methods and (information and communication) technologies (or bullshit buzzwords)](#methods-and-information-and-communication-technologies-or-bullshit-buzzwords)
    - [Examples in Smart City Planning and Policy Making](#examples-in-smart-city-planning-and-policy-making)
  - [Reasons](#reasons)
    - [Climate](#climate)
    - [Safety](#safety)
    - [Efficiency](#efficiency)
    - [Experience / Cost](#experience-cost)
  - [Implementation](#implementation)
    - [Implementing ITS with information and communication technology](#implementing-its-with-information-and-communication-technology)
      - [Information needed](#information-needed)
      - [Communication needed](#communication-needed)
    - [Vehicle to everything: V2X](#vehicle-to-everything-v2x)
    - [Data sources](#data-sources)
      - [Smart Infrastructure: Road sensors](#smart-infrastructure-road-sensors)
      - [Smart Vehicles: Vehicle mounted sensors](#smart-vehicles-vehicle-mounted-sensors)
      - [Vulnerable Road Users (VRU): Sensors carried by VRUS](#vulnerable-road-users-vru-sensors-carried-by-vrus)
    - [Perception](#perception)
      - [Vehicle-Road-Cloud Integration System (VRCIS)](#vehicle-road-cloud-integration-system-vrcis)
      - [Collaborative perception](#collaborative-perception)
      - [Cross domain perception: not only spatial (shape), for example also traffic flow](#cross-domain-perception-not-only-spatial-shape-for-example-also-traffic-flow)
  - [Summary: Smart mobility (Seems important)](#summary-smart-mobility-seems-important)
<!--toc:end-->

## Introduction to ITS: A key component in smart cities

### Variants:

- Surface ITS
- Air transport
- Maritime

### Methods and (information and communication) technologies (or bullshit buzzwords)

- Fancy words used to achieve ITS, they are interconnected to each other
- Also called features (? TODO verify in tutorial)
- Smart sensing and computing
    - Using mobile data
    - Wearables sensing
    - Vehicle based sensing
- Smart performance
    - Automation
    - Real-time information
    - Dynamic optimization
- Smart Travel behavior
    - Efficiency
    - Reliability
    - Safety
- Smart Infrastructure
    - Active travel
    - Shared travel
    - Data driven
- Smart city planning and policy making
    - Integrated development & Spatial planning
    - Transportation & Traffic strategy
    - Environment and public safety
- Multi modal systems (????)

### Examples in Smart City Planning and Policy Making

- Smart intersections: reduce traffic jam, allow ambulance to pass with priority
- Vehicle sharing
- Active travel aka. walking: environment friendly
- Public transport: Optimizes wait, and increases reliability

## Reasons

### Climate

- Current situation: Climate changes leads to more extreme weather:
    - Temperature
        - Greenhouse gas emission
    - Air pollution
- ITS Vehicle features helps protecting the environment (Didn't elaborate):
    - Speed vs. Pollutant: finding optimum speed for least $CO_2$
    - BEV (Battery-based Electric Vehicles) vs. ICEV (Internal Combustion Engine
      Vehicles):
        - The emission of $CO_2$ during the life-cycle: manufacture, usage,
          maintenance
    - Optimizing the occupancy of public transport: the occupancy level (how
      many people it holds) vs. The energy used
        - $$Railways \gt Aircraft \gt Buses \gt LightVehicles$$

### Safety

- Current situation: Car accidents
    - Driver failed to look properly
    - Driver careless, reckless or in a hurry
    - Failed to judge other's speed
- ITS features can help to avoid accidents caused by drivers (Didn't elaborate)

### Efficiency

- Current situation: People spend a lot of time waiting for traffic jams
- ITS feature can help reduce traffic congestion (Didn't elaborate)

### Experience / Cost

- ITS feature can help to improve public transport experience and cost.

## Implementation

### Implementing ITS with information and communication technology

#### Information needed

- Vehicle data
- System data: infrastructure status, traffic, parking spaces
- Intelligence: insights provided by data centers or cloud servers, by mining
  data from the aforementioned sources or other sources

#### Communication needed

- Wireless
- Mobile network
- Road Side Unit (RSU): ICT(Information and Communication Technologies) gateway
  deployed by the side of the road to facilitate wireless communication with
  cars.

### Vehicle to everything: V2X

- Four types of communications
    - V2V: Vehicle to vehicle
    - V2I: Vehicle to infrastructure
    - V2N: Vehicle to network
    - V2P: Vehicle to pedestrian
- Usage:
    - Use RSU to connect to network
    - Use V2I to monitor traffic
    - Use V2V for safety and ADAS
    - Use V2N to provide over the top cloud services

### Data sources

#### Smart Infrastructure: Road sensors

- Disruptive vs Non-disruptive:
    - ![sensors](./assets/2-sensors.webp)

#### Smart Vehicles: Vehicle mounted sensors

- Radar: long range
- Camera: efficient cost and FOV
- Lidar: depth, mid range
- Ultrasonic: Low cost, short range

#### Vulnerable Road Users (VRU): Sensors carried by VRUS

- Road safety in cities
- Technologies:
    - No tech: gesture
    - Wireless tech: P2X cycle bag
    - Visual tech: LED on cloth
    - Control tech

### Perception

#### Vehicle-Road-Cloud Integration System (VRCIS)

- Integrates with cloud:
    - Local: On board, millisecond level
    - Cloud:
        - Edge cloud, 100 ms
        - Region cloud, seconds
        - Central cloud, sub-minute
- More processing the higher you go

#### Collaborative perception

- This is spatial only
- Based on VRCIS, has a physical layer vs. cyber layer
    - Physical layer(vehicle side, road side, VRU side) provides data /
      insights, and send it to
    - Cyber layer(edge, region, central cloud), which generates perceptual
      fusion, then send it back to
    - Physical layer, to give collaborative perception
- Single Node: Perception Fusion Method
    - Single view
    - Multi view: many more sensors on a single node
- Multi Node: collaborative view, vehicle side and road side donate data that's
  coupled together, so a cloud can have better analysis

#### Cross domain perception: not only spatial (shape), for example also traffic flow

- Macroscopic traffic flow: use image, spatial and time
- Microscopic: use many image

## Summary: Smart mobility (Seems important)

- Definition: Existing Transportation systems augment with ICT.
- Intelligent vs. Smart:
    - Intelligent when it offer insights and human act on these;
    - Smart when it acts independently on insights in near-real time.
- Reason:
    - For safer, more efficient, more environment friendly, better experience,
      more inclusive, and more.
- Implementation:
    - Deploy sensors in vehicles, roads, VRUs
    - Allow them to communicate
    - Allow them to exchange information with other infrastructure (e.g., mobile
      network)
    - Allow them to analyse/interpret data
    - Allow them to communicate to generate collaborative knowledge
